@@ -102,7 +102,7 @@ class VersionHandler(IPythonHandler):
     async def get(self):
         global domain
         try:
-            self.write(__version__)
+            self.write(json.dumps({'version': __version__, 'userHome': userHome, 'jupyterHome': jupyterHome}))
         except Exception as e:
             # 401 unauthorized
             self.set_status(401)
@@ -344,10 +344,11 @@ class LaunchNotebookHandler(IPythonHandler):
             data = json.loads(self.request.body)
             requirementsFile = data.get('requirementsFile')     # we use .get() for params that are not required
             paths = data.get('paths')
-            hashes = [hash_file(f) for f in paths]
-            stats = [os.stat(f) for f in paths]
-            lastModifieds = [datetime.datetime.fromtimestamp(stat.st_mtime).isoformat() + 'Z' for stat in stats]
-            sizes = [str(stat.st_size) for stat in stats]
+            expanded = [] if paths is None else [os.path.expanduser(f) for f in paths]
+            hashes = [hash_file(f) for f in expanded]
+            stats = [os.stat(f) if os.path.isfile(f) else None for f in expanded]
+            lastModifieds = [datetime.datetime.fromtimestamp(stat.st_mtime).isoformat() + 'Z' if stat != None else str(None) for stat in stats]
+            sizes = [str(stat.st_size) if stat else str(None) for stat in stats]
             uuid = data['uuid']
             timestamp = data['timestamp']
             IOLoop.current().run_in_executor(None, launch_notebook, requirementsFile, hashes, paths, lastModifieds, sizes, uuid, timestamp)
@@ -822,7 +823,7 @@ class UploadFilesHandler(IPythonHandler):
         try:
             data = json.loads(self.request.body)
             key = data['key']
-            paths = data['paths']
+            paths = [os.path.expanduser(path) for path in data['paths']]
             compress = data['compress']
             IOLoop.current().run_in_executor(None, upload_files, key, paths, compress)
             self.write(json.dumps({'message': 'success'}))
@@ -2078,14 +2079,16 @@ def create_checkout(items, redirect):
 ####
 
 def hash_file(fileName):
-    BLOCKSIZE = 65536
-    hasher = hashlib.md5()
-    with open(fileName, 'rb') as afile:
-        buf = afile.read(BLOCKSIZE)
-        while len(buf) > 0:
-            hasher.update(buf)
+    if os.path.isfile(fileName):
+        BLOCKSIZE = 65536
+        hasher = hashlib.md5()
+        with open(fileName, 'rb') as afile:
             buf = afile.read(BLOCKSIZE)
-    return hasher.hexdigest().upper()
+            while len(buf) > 0:
+                hasher.update(buf)
+                buf = afile.read(BLOCKSIZE)
+        return hasher.hexdigest().upper()
+    return str(None)
 
 ###############################################################################################
 ####    Zip files
