@@ -30,6 +30,17 @@ export class Global {
         Global._onVersionSet.emit(void 0);
     }
 
+    public static userHome: string = undefined;
+    public static jupyterHome: string = undefined;
+
+    public static convertJupyterPathToOptumiPath = (path: string) => {
+        return (Global.jupyterHome + '/' + path).replace(Global.userHome, '~')
+    }
+
+    public static convertOptumiPathToJupyterPath = (path: string) => {
+        return path.replace('~', Global.userHome).replace(Global.jupyterHome + '/', '')
+    }
+
     private static _onVersionSet: Signal<Global, string> = new Signal<Global, string>(Global.emitter)
     public static get onVersionSet(): Signal<Global, string> { return Global._onVersionSet }
 
