@@ -18,7 +18,7 @@ import { IThemeManager } from '@jupyterlab/apputils';
 import CssBaseline from '@material-ui/core/CssBaseline';
 import {
 	ThemeProvider,
-	createMuiTheme,
+	createTheme,
 	Theme,
     withStyles,
     StyledComponentProps, 
@@ -113,7 +113,7 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
 
 	private getTheme = () => {
 		var themeManager: IThemeManager = Global.themeManager;
-		return createMuiTheme({
+		return createTheme({
 			props: {
 				MuiOutlinedInput: { inputProps: { spellCheck: 'false' }}
 			},
