@@ -178,8 +178,7 @@ export class Login extends React.Component<IProps, IState> {
                     {/* <div dangerouslySetInnerHTML={{__html: this.fbWidget.node.innerHTML}} /> */}
                 </Container>
 			<StyledDialog
-                disableBackdropClick
-                disableEscapeKeyDown
+				onClose={(event: object, reason: string) => void 0}
                 open={this.state.packageString != ""}
             >
 				<DialogTitle
