@@ -8,10 +8,13 @@
 import * as React from 'react';
 import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
 import { TextBox, SubHeader } from '../../core';
-import { OutlinedInput, IconButton, Accordion, AccordionSummary, AccordionDetails, withTheme, Theme, CircularProgress, Button } from '@material-ui/core';
+import { OutlinedInput, IconButton, Accordion, AccordionSummary, AccordionDetails, withTheme, Theme, CircularProgress, Button, Checkbox } from '@material-ui/core';
 import { Global } from '../../Global';
 import { FileUploadConfig } from '../../models/FileUploadConfig';
 import CloseIcon from '@material-ui/icons/Close'
+import CachedIcon from '@material-ui/icons/Cached'
+import CheckBoxOutlineBlankIcon from '@material-ui/icons/CheckBoxOutlineBlank';
+import CheckBoxIcon from '@material-ui/icons/CheckBox';
 import { UploadConfig } from '../../models/UploadConfig';
 import FileServerUtils from '../../utils/FileServerUtils';
 import { OptumiMetadataTracker } from '../../models/OptumiMetadataTracker';
@@ -103,7 +106,8 @@ interface IProps {
 interface IState {
     filePath: string
     // Here is where we will keep a list of the file paths that were entered successfully but no longer exist on the disk
-    problemFiles: string[]
+    localProblemFiles: string[]
+    cloudProblemFiles: string[]
     problemDataConnectors: string[]
     filesTooBig: FileMetadata[]
 }
@@ -123,7 +127,8 @@ class FilesPanel extends React.Component<IProps, IState> {
         this.textField = React.createRef()
         this.state = {
             filePath: '',
-            problemFiles: [],
+            localProblemFiles: [],
+            cloudProblemFiles: [],
             problemDataConnectors: [],
             filesTooBig: [],
         }
@@ -191,11 +196,32 @@ class FilesPanel extends React.Component<IProps, IState> {
         return false;
     }
 
+    
+    key = 0
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         const optumi = Global.metadata.getMetadata().config;
         const files = optumi.upload.files;
         const dataConnectors = optumi.upload.dataConnectors;
+        var yellowTriangle = false
+        var redTriangle = false
+        for (let file of files) {
+            if (file.enabled) {
+                if (this.state.localProblemFiles.includes(file.path)) {
+                    yellowTriangle = true
+                    if (this.state.cloudProblemFiles.includes(file.path)) {
+                        redTriangle = true
+                    }
+                }
+            }
+        }
+        for (let dataConnector of dataConnectors) {
+            if (dataConnector.enabled) {
+                if (this.state.problemDataConnectors.includes(dataConnector.name)) {
+                    redTriangle = true
+                }
+            }
+        }
         return (
             <div style={this.props.style}>
                 <StyledAccordion
@@ -311,7 +337,11 @@ class FilesPanel extends React.Component<IProps, IState> {
                                 }
                             />
                         </div>
-                        {(this.state.problemFiles.length > 0 || this.state.problemDataConnectors.length > 0) && <WarningRounded fontSize={'small'} style={{color: this.props.theme.palette.error.main, marginTop: '4px'}} />}
+                        {(yellowTriangle || redTriangle) && (
+                            <ExtraInfo reminder={redTriangle ? 'Files are missing, both locally and in cloud storage. Your notebook will not be able to use them.' : 'Files are missing locally. Your notebook will be able to run with files in cloud storage but we will not be able to sync them with local copies.'}>
+                                <WarningRounded fontSize={'small'} style={{color: redTriangle ? this.props.theme.palette.error.main : this.props.theme.palette.warning.main, marginTop: '4px'}} />
+                            </ExtraInfo>
+                        )}
                         <span style={{
                             margin: 'auto 15px',
                             flexGrow: 1,
@@ -354,6 +384,7 @@ class FilesPanel extends React.Component<IProps, IState> {
                             <AddFilesPopup onFilesAdded={async (metadatas: FileMetadata[]) => {
                                 const filesTooBig = [];
                                 for (let fileModel of metadatas) {
+                                    fileModel.path = Global.convertJupyterPathToOptumiPath(fileModel.path)
                                     // Don't try to add the same file/directory more than once
                                     if (this.pathHasError(fileModel.path)) continue;
                                     const tracker = Global.metadata
@@ -367,11 +398,11 @@ class FilesPanel extends React.Component<IProps, IState> {
                                                 path: fileModel.path,
                                                 type: fileModel.type,
                                                 mimetype: fileModel.mimetype,
-                                                files: [fileModel.path]
+                                                enabled: true,
                                             }))
                                         }
                                     } else {
-                                        const directoryContents = (await FileServerUtils.getRecursiveTree(fileModel.path))
+                                        const directoryContents = (await FileServerUtils.getRecursiveTree(Global.convertOptumiPathToJupyterPath(fileModel.path)))
                                         const directoryPaths = []
                                         for (let metadata of directoryContents) {
                                             if (metadata.size > Global.MAX_UPLOAD_SIZE) {
@@ -385,7 +416,7 @@ class FilesPanel extends React.Component<IProps, IState> {
                                                 path: fileModel.path,
                                                 type: fileModel.type,
                                                 mimetype: fileModel.mimetype,
-                                                files: directoryPaths,
+                                                enabled: true,
                                             }))
                                         }
                                     }
@@ -426,8 +457,8 @@ class FilesPanel extends React.Component<IProps, IState> {
                             <>
                                 {files.map(
                                     (value: FileUploadConfig) => (
-                                        <ResourceFile
-                                            key={value.path}
+                                        <ThemedResourceFile
+                                            key={value.path + this.key++}
                                             file={value}
                                             handleFileDelete={() => {
                                                 // Cancel the upload
@@ -449,16 +480,32 @@ class FilesPanel extends React.Component<IProps, IState> {
                                                 }
                                                 // optumi.upload.files = (optumi.upload.files as UploadVarMetadata[]).filter(x => x.path !== (event.currentTarget as HTMLButtonElement).id.replace('-delete', ''));
                                                 tracker.setMetadata(optumi);
-                                                if (this.state.problemFiles.includes(value.path)) this.safeSetState({ problemFiles: this.state.problemFiles.filter(x => x != value.path) });
+                                                if (this.state.localProblemFiles.includes(value.path)) this.safeSetState({ localProblemFiles: this.state.localProblemFiles.filter(x => x != value.path) });
+                                                if (this.state.cloudProblemFiles.includes(value.path)) this.safeSetState({ cloudProblemFiles: this.state.cloudProblemFiles.filter(x => x != value.path) });
                                             }}
-                                            noLongerExists={this.state.problemFiles.includes(value.path)}
+                                            handleFileEnabledChange={(enabled: boolean) => {
+                                                const tracker: OptumiMetadataTracker = Global.metadata;
+                                                const optumi = tracker.getMetadata();
+                                                const upload: UploadConfig = optumi.config.upload;
+                                                const files = upload.files;
+                                                for (var i = 0; i < files.length; i++) {
+                                                    const file = files[i];
+                                                    if (file.path === value.path) {
+                                                        file.enabled = enabled;
+                                                        break;
+                                                    }
+                                                }
+                                                tracker.setMetadata(optumi);
+                                            }}
+                                            missingLocally={this.state.localProblemFiles.includes(value.path)}
+                                            missingInCloud={this.state.cloudProblemFiles.includes(value.path)}
                                         />
                                     )
                                 )}
                                 {dataConnectors.map(
                                     (value: DataConnectorUploadConfig) => (
                                         <ResourceDataConnector
-                                            key={value.name}
+                                            key={value.name + this.key++}
                                             dataConnector={value}
                                             handleFileDelete={() => {
                                                 const tracker: OptumiMetadataTracker = Global.metadata;
@@ -514,54 +561,83 @@ class FilesPanel extends React.Component<IProps, IState> {
         )
     }
 
-    private refreshFiles = async () => {
+    private refreshFiles = async (poll: boolean = true) => {
         if (this.refreshingFiles) {
-            if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-            const optumi = Global.metadata.getMetadata().config;
-            const files = optumi.upload.files;
-            for (var file of files) {
-                if (!this.refreshingFiles) break;
-                Global.user.fileTracker.uploadFiles({ path: file.path, type: file.type } as FileMetadata);
-                if (!this.state.problemFiles.includes(file.path)) {
-                    const barr = await FileServerUtils.checkIfPathExists(file.path);
+            try {
+                var newLocalProblemFiles = [];
+                var newCloudProblemFiles = [];
+                const optumi = Global.metadata.getMetadata().config;
+                const files = optumi.upload.files;
+                const fileTracker = Global.user.fileTracker;
+                for (var file of files) {
+                    if (!this.refreshingFiles) break;
+                    // Check local
+                    const barr = await FileServerUtils.checkIfPathExists(Global.convertOptumiPathToJupyterPath(file.path));
                     if (!barr[0]) {
-                        this.safeSetState({ problemFiles: this.state.problemFiles.concat([file.path]) });
+                        newLocalProblemFiles.push(file.path);
+                    } else {
+                        // This upload call will 'sync' the file if necessary
+                        Global.user.fileTracker.uploadFiles({ path: file.path, type: file.type } as FileMetadata);
                     }
-                }
-            }
-            setTimeout(this.refreshFiles, 60000);
-        }
-    }
-
-    private refreshDataConnectors = async () => {
-        if (this.refreshingDataConnectors) {
-            if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-            const optumi = Global.metadata.getMetadata().config;
-            const dataConnectors = optumi.upload.dataConnectors;
-            
-            const settings = ServerConnection.makeSettings();
-            const url = settings.baseUrl + "optumi/get-data-connectors";
-            const dataConnectorsFromController: DataConnectorMetadata[] = await (ServerConnection.makeRequest(url, {}, settings).then(response => {
-                if (response.status !== 200) throw new ServerConnection.ResponseError(response);
-                return response.json();
-            }).then((json: any) => json.connectors));
-
-            for (var dataConnector of dataConnectors) {
-                if (!this.refreshingDataConnectors) break;
-                if (!this.state.problemDataConnectors.includes(dataConnector.name)) {
-                    const exists = dataConnectorsFromController.map(x => x.name).includes(dataConnector.name);
+                    // Check cloud
+                    const exists = file.type === 'directory' ? fileTracker.directoryExists(file.path) : fileTracker.pathExists(file.path)
                     if (!exists) {
-                        this.safeSetState({ problemDataConnectors: this.state.problemDataConnectors.concat([dataConnector.name]) });
+                        newCloudProblemFiles.push(file.path)
                     }
                 }
+                
+                this.safeSetState({ localProblemFiles: newLocalProblemFiles, cloudProblemFiles: newCloudProblemFiles });
+            } catch (err) {
+                console.error(err)
+            }
+            if (poll) {
+                if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
+                setTimeout(this.refreshFiles, 60000);
             }
-            setTimeout(this.refreshDataConnectors, 60000);
         }
     }
 
-    private handleDataConnectorChange = () => this.refreshDataConnectors()
+    private refreshDataConnectors = async (poll: boolean = true) => {
+        if (this.refreshingDataConnectors) {
+            try {
+                const optumi = Global.metadata.getMetadata().config;
+                const dataConnectors = optumi.upload.dataConnectors;
+                
+                const settings = ServerConnection.makeSettings();
+                const url = settings.baseUrl + "optumi/get-data-connectors";
+                const dataConnectorsFromController: DataConnectorMetadata[] = await (ServerConnection.makeRequest(url, {}, settings).then(response => {
+                    if (response.status !== 200) throw new ServerConnection.ResponseError(response);
+                    return response.json();
+                }).then((json: any) => json.connectors));
 
-    private handleMetadataChange = () => {this.forceUpdate()}
+                for (var dataConnector of dataConnectors) {
+                    if (!this.refreshingDataConnectors) break;
+                    if (!this.state.problemDataConnectors.includes(dataConnector.name)) {
+                        const exists = dataConnectorsFromController.map(x => x.name).includes(dataConnector.name);
+                        if (!exists) {
+                            this.safeSetState({ problemDataConnectors: this.state.problemDataConnectors.concat([dataConnector.name]) });
+                        }
+                    }
+                }
+            } catch (err) {
+                console.error(err)
+            }
+            if (poll) {
+                if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
+                setTimeout(this.refreshDataConnectors, 60000);
+            }
+        }
+    }
+
+    private handleDataConnectorChange = () => {
+        this.refreshDataConnectors(false)
+    }
+
+    private handleMetadataChange = () => {
+        this.refreshDataConnectors(false)
+        this.refreshFiles(false)
+        this.forceUpdate()
+    }
 	private handleLabShellChange = () => {this.forceUpdate()}
 
 	// Will be called automatically when the component is mounted
@@ -624,12 +700,16 @@ export { ThemedFilesPanel as FilesPanel }
 
 interface RFProps {
     file: FileUploadConfig,
+    handleFileEnabledChange: (enabled: boolean) => void,
     handleFileDelete: () => void,
-    noLongerExists?: boolean,
+    missingLocally: boolean,
+    missingInCloud: boolean,
+    theme: Theme,
 }
 
 interface RFState {
     hovering: boolean,
+    fileSync: boolean,
 }
 
 class ResourceFile extends React.Component<RFProps, RFState> {
@@ -639,6 +719,7 @@ class ResourceFile extends React.Component<RFProps, RFState> {
         super(props)
         this.state = {
             hovering: false,
+            fileSync: this.props.file.enabled,
         }
     }
 
@@ -647,6 +728,33 @@ class ResourceFile extends React.Component<RFProps, RFState> {
         const progress = Global.user.fileTracker.get(this.props.file.path);
         const compression = progress.filter(x => x.type == 'compression');
         const upload = progress.filter(x => x.type == 'upload');
+
+        // Decide what color to make this
+        // Green is if the file exists on the disk and can be synced
+        // Yellow is if it doesn't exist on the disk but exists in the cloud so we can still run
+        // Red is if it doesn't exist locally or in the cloud so we can't run
+        // Always show is set based on color (green/gray false, red/orange true)
+        const palette = this.props.theme.palette;
+        var syncColor;
+        var alwaysShowFileSync;
+        if (this.state.fileSync) {
+            if (!this.props.missingLocally) {
+                syncColor = palette.success.main;
+                alwaysShowFileSync = false;
+            } else {
+                if (!this.props.missingInCloud) {
+                    syncColor = palette.warning.main;
+                    alwaysShowFileSync = true;
+                } else {
+                    syncColor = palette.error.main;
+                    alwaysShowFileSync = true;
+                }
+            }
+        } else {
+            syncColor = palette.text.disabled;
+            alwaysShowFileSync = false;
+        }
+
         return (
             <div
                 style={{display: 'flex', width: '100%', position: 'relative'}}
@@ -657,6 +765,28 @@ class ResourceFile extends React.Component<RFProps, RFState> {
                     this.safeSetState({hovering: false})
                 }}
             >
+                <div style={{
+                    position: 'absolute',
+                    left: '-10px',
+                    paddingTop: '3px', // The checkbox is 16px, the line is 22px
+                    display: 'inline-flex',
+                    background: 'var(--jp-layout-color1)',
+                    opacity: this.state.hovering ? '1' : '0',
+                    transition: easeAnimation,
+                }}>
+                    <Checkbox
+                        disableRipple
+                        checked={this.state.fileSync}
+                        style={{padding: '0px'}}
+                        icon={<CheckBoxOutlineBlankIcon style={{width: '16px', height: '16px'}} />}
+                        checkedIcon={<CheckBoxIcon style={{width: '16px', height: '16px'}} />}
+                        onClick={() => {
+                            let newFileSync = !this.state.fileSync
+                            this.safeSetState({fileSync: newFileSync})
+                            this.props.handleFileEnabledChange(newFileSync);
+                        }}
+                    />
+                </div>
                 <div style={{
                     position: 'absolute',
                     right: '-10px',
@@ -675,43 +805,72 @@ class ResourceFile extends React.Component<RFProps, RFState> {
                         <CloseIcon style={{position: 'relative', width: '16px', height: '16px'}} />
                     </IconButton>
                 </div>
+                <div style={{
+                    position: 'absolute',
+                    right: '9px',
+                    paddingTop: '3px', // The checkbox is 16px, the line is 22px
+                    display: 'inline-flex',
+                    transition: easeAnimation,
+                }}>
+                    {(!this.props.missingLocally && (compression.length > 0 || (upload.length > 0 && upload[0].total < 0))) ? (
+                        <ExtraInfo reminder={compression.length > 0 ? compression[0].total == -1 ? '' : 'Compressed ' + compression[0].progress + '/' + compression[0].total + ' files' : ''}>
+                            <div style={{height: '16px', width: '16px', background: 'var(--jp-layout-color1)'}}>
+                                <CircularProgress
+                                    color='primary'
+                                    size='14px'
+                                    thickness={8}
+                                    style={{margin: 'auto'}}
+                                />
+                            </div>
+                        </ExtraInfo>
+                    ) : (!this.props.missingLocally && (upload.length > 0) ? (
+                        <ExtraInfo reminder={FormatUtils.styleCapacityUnitValue()(upload[0].progress) + '/' + FormatUtils.styleCapacityUnitValue()(upload[0].total)}>
+                            <div style={{height: '16px', width: '16px', background: 'var(--jp-layout-color1)'}}>
+                                <CircularProgress
+                                    variant='determinate'
+                                    size='14px'
+                                    thickness={8}
+                                    style={{margin: 'auto'}}
+                                    value={(upload[0].progress / upload[0].total) * 100 }
+                                />
+                            </div>
+                        </ExtraInfo>
+                    ) : (
+                        <CachedIcon style={{
+                            position: 'relative',
+                            width: '16px',
+                            height: '16px',
+                            transform: 'scaleX(-1)',
+                            color: this.state.fileSync ? syncColor : 'var(--jp-ui-font-color2)',
+                            background: 'var(--jp-layout-color1)',
+                            opacity: this.state.hovering || alwaysShowFileSync ? this.state.fileSync ? '0.87' : '0.54' : '0',
+                        }} />
+                    ))}
+                </div>
                 <div
                     style={{
                         width: '100%',
                         fontSize: '12px',
                         lineHeight: '14px',
                         padding: '3px 6px 3px 6px',
-                        display: 'inline-flex'
+                        display: 'inline-flex',
                     }}
                 >
-                    {(!this.props.noLongerExists && (compression.length > 0 || (upload.length > 0 && upload[0].total < 0))) ? (
-                        <ExtraInfo reminder={compression.length > 0 ? compression[0].total == -1 ? '' : 'Compressed ' + compression[0].progress + '/' + compression[0].total + ' files' : ''}>
-                            <div style={{height: '16px', width: '16px', marginRight: '4px'}}>
-                                <CircularProgress color="primary" size='14px' thickness={8} style={{margin: 'auto'}}/>
-                            </div>
-                        </ExtraInfo>
-                    ) : (!this.props.noLongerExists && (upload.length > 0) ? (
-                        <ExtraInfo reminder={FormatUtils.styleCapacityUnitValue()(upload[0].progress) + '/' + FormatUtils.styleCapacityUnitValue()(upload[0].total)}>
-                            <div style={{height: '16px', width: '16px', marginRight: '4px'}}>
-                                <CircularProgress variant="determinate" size='14px' thickness={8} style={{margin: 'auto'}} value={(upload[0].progress / upload[0].total) * 100 } />
-                            </div>
-                        </ExtraInfo>
-                    ) : (
-                        <DirListingItemIcon
-                            fileType={this.props.file.type}
-                            mimetype={this.props.file.mimetype}
-                        />
-                    ))}
+                    <DirListingItemIcon
+                        fileType={this.props.file.type}
+                        mimetype={this.props.file.mimetype}
+                        style={{marginRight: '0px', opacity: this.state.fileSync ? '0.87' : '0.54'}}
+                    />
                     <div
                         style={{
                             margin: 'auto 0px',
                             overflow: 'hidden', 
-                            color: this.props.noLongerExists ? '#f48f8d' : ''
+                            color: this.state.fileSync ? 'var(--jp-ui-font-color1)' : 'var(--jp-ui-font-color2)', // this.props.noLongerExists ? '#f48f8d' : ''
                         }}
                         title={
                             (this.props.file.path.includes('/') ? (
 `Name: ${this.props.file.path.split('/').pop()}
-Path: ${this.props.file.path.replace(/\/[^\/]*$/, '')}`
+Path: ${this.props.file.path.replace(/\/[^\/]*$/, '/')}`
                             ) : (
 `Name: ${this.props.file.path.split('/').pop()}`
                             ))
@@ -723,7 +882,7 @@ Path: ${this.props.file.path.replace(/\/[^\/]*$/, '')}`
                             textOverflow: 'ellipsis', 
                             whiteSpace: 'nowrap',
                         }}>
-                            {this.props.file.path + (this.props.noLongerExists ? ' (no longer exists)' : '')}
+                            {Global.convertOptumiPathToJupyterPath(this.props.file.path)}
                         </div>
                     </div>
                 </div>
@@ -777,6 +936,8 @@ Path: ${this.props.file.path.replace(/\/[^\/]*$/, '')}`
     }
 }
 
+const ThemedResourceFile = withTheme(ResourceFile)
+
 interface RDCProps {
     dataConnector: DataConnectorUploadConfig,
     handleFileDelete: () => void,
