@@ -8,6 +8,7 @@
 import * as React from 'react'
 import { fileIcon, folderIcon, html5Icon, imageIcon, jsonIcon, markdownIcon, notebookIcon, pythonIcon, spreadsheetIcon, yamlIcon } from '@jupyterlab/ui-components'
 import { Global } from '../../../Global';
+import { CSSProperties } from '@material-ui/core/styles/withStyles';
 
 interface FileType {
     extension: string,
@@ -90,6 +91,7 @@ const fileTypes: FileType[] = [
 interface IProps {
     fileType: 'notebook' | 'file' | 'directory'
     mimetype: string
+    style?: CSSProperties
 }
 
 interface IState {}
@@ -103,7 +105,7 @@ export default class DirListingItemIcon extends React.Component<IProps, IState>
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <span className='jp-DirListing-itemIcon'>
+            <span className='jp-DirListing-itemIcon' style={this.props.style}>
                 {this.props.fileType === 'notebook' ? (
                     <notebookIcon.react display='block'/>
                 ) : this.props.fileType === 'directory' ? (
