@@ -15,7 +15,7 @@ import {
 import ChevronLeft from '@material-ui/icons/ChevronLeft';
 import ChevronRight from '@material-ui/icons/ChevronRight';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
-import { Expertise } from '../../../models/OptumiMetadata';
+import { Expertise } from '../../../models/OptumiConfig';
 
 interface IProps {
     getValue: (tracker: OptumiMetadataTracker) => Expertise
