@@ -15,11 +15,13 @@ interface IProps {
     tooltip?: string
     getValue: () => boolean
     saveValue: (value: boolean) => void
-    label: string
+    label?: string
     labelWidth?: string
+    labelBefore?: boolean;
     flip?: boolean
     ref?: any
     disabled?: boolean
+    color?: string
     onMouseOver?: (...args: any[]) => any
     onMouseOut?: (...args: any[]) => any
 }
@@ -28,7 +30,7 @@ interface IState {
     value: boolean,
 }
 
-export const getStyledSwitch = () => {
+export const getStyledSwitch = (color: string = '#10A0F9') => {
     return withStyles({
         root: {
             width: '42px',
@@ -43,6 +45,15 @@ export const getStyledSwitch = () => {
         },
         switchBase: {
             padding: '0px',
+            '&$checked': {
+                color: color,
+            },
+            '&$checked + $track': {
+                backgroundColor: color,
+            },
+        },
+        checked: {
+            color: color,
         },
         track: {
             height: '12px',
@@ -61,7 +72,7 @@ export class Switch extends React.Component<IProps, IState> {
 
     public constructor(props: IProps) {
         super (props);
-        this.StyledSwitch = getStyledSwitch();
+        this.StyledSwitch = getStyledSwitch(props.color);
         this.state = { value: this.props.getValue() }
     }
 
@@ -71,24 +82,27 @@ export class Switch extends React.Component<IProps, IState> {
             <div
                 style={Object.assign({
                     display: 'inline-flex',
-                    width: '100%',
+                    width: this.props.label ? '100%' : undefined,
                     padding: '6px 0px',
-                    direction: this.props.flip ? 'rtl' : 'ltr'
                 }, this.props.style)}
                 ref={this.props.ref}
                 onMouseOver={this.props.onMouseOver}
                 onMouseOut={this.props.onMouseOut}
             >
+                {this.props.label && this.props.labelBefore && (
+                    <div style={{width: '100%', textAlign: 'left', margin: 'auto 12px'}}>
+                        {this.props.label}
+                    </div>
+                )}
                 <ExtraInfo reminder={this.props.tooltip || ''}>
                     <div 
                         style={{
-                        minWidth: this.props.labelWidth || '68px',
+                        minWidth: this.props.labelWidth || 'unset',
                         lineHeight: '24px',
                         textAlign: 'center',
-                        margin: '0px 12px',
+                        direction: this.props.flip ? 'rtl' : 'ltr'
                     }}>
                         <this.StyledSwitch
-                            color='primary'
                             inputProps={{style: {height: '24px'}}}
                             checked={this.state.value}
                             onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
@@ -99,16 +113,18 @@ export class Switch extends React.Component<IProps, IState> {
                         />
                     </div>
                 </ExtraInfo>
-                <div style={{width: '100%', textAlign: this.props.flip ? 'right' : 'left', margin: 'auto 6px'}}>
-                    {this.props.label}                    
-                </div>
+                {this.props.label && (this.props.labelBefore == undefined || this.props.labelBefore == false) && (
+                    <div style={{width: '100%', textAlign: 'left', margin: 'auto 6px'}}>
+                        {this.props.label}                    
+                    </div>
+                )}
             </div>
         )
     }
 
     private handleMetadataChange = () => { this.safeSetState({value: this.props.getValue()}) }
     private handleThemeChange = () => {
-        this.StyledSwitch = getStyledSwitch()
+        this.StyledSwitch = getStyledSwitch(this.props.color)
         this.forceUpdate();
     }
 
