@@ -118,9 +118,9 @@ export class FileTracker {
 
         const paths = [];
         if (metadata.type == 'directory') {
-            for (let file of (await FileServerUtils.getRecursiveTree(metadata.path))) {
+            for (let file of (await FileServerUtils.getRecursiveTree(Global.convertOptumiPathToJupyterPath(metadata.path)))) {
                 if (file.size <= Global.MAX_UPLOAD_SIZE) {
-                    paths.push(file.path);
+                    paths.push(Global.convertJupyterPathToOptumiPath(file.path));
                 }
             }
         } else {
@@ -462,7 +462,11 @@ export class FileTracker {
 			settings
 		).then((response: Response) => {
 			Global.handleResponse(response);
-		});
+            return response.text();
+		}).then(() => {
+            // The delete request could have resulted in a file being disabled, 
+            Global.metadata.refreshMetadata()
+        });
 	}
 
     private filesPollDelay = 30000;
@@ -562,13 +566,32 @@ export class FileTracker {
     }
 
     public fileExists = (metadata: FileMetadata): boolean => {
-        const match = metadata.hash + metadata.path;
-        for (let file of this._files) {
-            if (file.hash + file.path === match) return true;
+        if (this._files) {
+            const match = metadata.hash + metadata.path;
+            for (let file of this._files) {
+                if (file.hash + file.path === match) return true;
+            }
         }
         return false;
     }
 
+    public pathExists = (path: string): boolean => {
+        if (this._files) {
+            for (let file of this._files) {
+                if (file.path === path) return true;
+            }
+        }
+        return false;
+    }
+
+    public directoryExists = (path: string): boolean => {
+        if (this._files) {
+            for (let file of this._files) {
+                if (file.path.startsWith(path)) return true;
+            }
+        }
+        return false;
+    }
 
     public stopPolling = () => {
         this.polling = false;
