@@ -129,9 +129,6 @@ export class ProgressMessage {
         return false;
 	}
 
-	public loaded: number = 0;
-	public total: number = 0;
-
 	private sending = false;
 	private sendQueue : Update[] = [];
 
