@@ -50,7 +50,6 @@ export class User {
             responseData.maxMachines,
             responseData.machinesCap,
             responseData.userExpertise,
-            responseData.proactiveUploadsEnabled,
 			responseData.compressFilesEnabled,
 			responseData.lastPage,
 			responseData.stopJobPreventEnabled,
@@ -60,6 +59,7 @@ export class User {
 			responseData.startSessionPreventEnabled,
 			responseData.notificationsEnabled,
 			responseData.snapToInventoryEnabled,
+			responseData.showMonitoringEnabled,
             new AppTracker(),
 			new FileTracker(),
             new Machines(machines, responseData.maxRate)
@@ -111,7 +111,6 @@ export class User {
     private _maxMachines: number;
     private _machinesCap: number;
 	private _userExpertise: number;
-	private _proactiveUploadsEnabled: boolean;
 	private _compressFilesEnabled: boolean;
 	private _lastPage: number;
 	private _stopJobPreventEnabled: boolean;
@@ -121,6 +120,7 @@ export class User {
 	private _startSessionPreventEnabled: boolean;
 	private _notificationsEnabled: boolean;
 	private _snapToInventoryEnabled: boolean;
+	private _showMonitoringEnabled: boolean;
 
 	private _appTracker: AppTracker;
 	private _fileTracker: FileTracker;
@@ -136,9 +136,9 @@ export class User {
         userRecommendations: number, maxRecommendations: number, recommendationsCap: number, 
         maxJobs: number, jobsCap: number, 
         maxMachines: number, machinesCap: number, 
-		userExpertise: number, proactiveUploadsEnabled: boolean, compressFilesEnabled: boolean, lastPage: number, 
+		userExpertise: number, compressFilesEnabled: boolean, lastPage: number, 
 		stopJobPreventEnabled: boolean, deleteJobPreventEnabled: boolean, noRequirementsPreventEnabled: boolean, noFileUploadsPreventEnabled: boolean, 
-		startSessionPreventEnabled: boolean, notificationsEnabled: boolean, snapToInventoryEnabled: boolean,
+		startSessionPreventEnabled: boolean, notificationsEnabled: boolean, snapToInventoryEnabled: boolean, showMonitoringEnabled: boolean,
 		appTracker: AppTracker, fileTracker: FileTracker, machines: Machines) {
         this._unsignedAgreement = unsignedAgreement === undefined ? true : unsignedAgreement;
         this._name = name;
@@ -165,7 +165,6 @@ export class User {
         this._machinesCap = machinesCap;
 
 		this._userExpertise = userExpertise;
-		this._proactiveUploadsEnabled = proactiveUploadsEnabled;
 		this._compressFilesEnabled = compressFilesEnabled;
 		this._lastPage = lastPage;
 		this._stopJobPreventEnabled = stopJobPreventEnabled;
@@ -175,6 +174,7 @@ export class User {
 		this._startSessionPreventEnabled = startSessionPreventEnabled;
 		this._notificationsEnabled = notificationsEnabled;
 		this._snapToInventoryEnabled = snapToInventoryEnabled;
+		this._showMonitoringEnabled = showMonitoringEnabled;
 
 		this._appTracker = appTracker;
 		this._fileTracker = fileTracker;
@@ -414,26 +414,6 @@ export class User {
 		return this._userExpertise;
 	}
 
-	set userExpertise(userExpertise: number) {
-		if (userExpertise === this._userExpertise) {
-			return;
-		}
-		this._userExpertise = userExpertise;
-		this.setUserInformation("userExpertise", userExpertise.toString());
-	}
-
-	get proactiveUploadsEnabled(): boolean {
-		return this._proactiveUploadsEnabled;
-	}
-
-	set proactiveUploadsEnabled(proactiveUploadsEnabled: boolean) {
-		if (proactiveUploadsEnabled === this._proactiveUploadsEnabled) {
-			return;
-		}
-		this._proactiveUploadsEnabled = proactiveUploadsEnabled;
-		this.setUserInformation("proactiveUploadsEnabled", proactiveUploadsEnabled.toString());
-	}
-
 	get compressFilesEnabled(): boolean {
 		return this._compressFilesEnabled;
 	}
@@ -542,6 +522,18 @@ export class User {
 		this.setUserInformation("snapToInventoryEnabled", snapToInventoryEnabled.toString());
 	}
 
+	get showMonitoringEnabled(): boolean {
+		return this._showMonitoringEnabled;
+	}
+
+	set showMonitoringEnabled(showMonitoringEnabled: boolean) {
+		if (showMonitoringEnabled === this._showMonitoringEnabled) {
+			return;
+		}
+		this._showMonitoringEnabled = showMonitoringEnabled;
+		this.setUserInformation("showMonitoringEnabled", showMonitoringEnabled.toString());
+	}
+
 	get fileTracker(): FileTracker {
 		return this._fileTracker;
 	}
