@@ -525,6 +525,20 @@ export class App {
 						this._modules.push(mod);
 						if (this.interactive) mod.startSessionHandler();
 					}
+					if (body.files) {
+						for (let i = 0; i < body.files.length; i++) {
+							if (body.files[i] != '') {
+								this._files.push({
+									last_modified: body.filesmod[i],
+									name: (body.files[i] as string).split('/').pop(),
+									path: body.files[i],
+									size: +body.filessize[i],
+									type: 'file',
+									hash: body.hashes[i],
+								} as FileMetadata);
+							}
+						}
+					}
 				} else if (body.status == "Failed") {
 					if (!this._initializing.completed) {
 						this._initializing.addUpdate(new Update(body.message || 'Initialization failed', ""));
@@ -571,12 +585,14 @@ export class App {
 
 		data.paths = [];
 		for (var uploadEntry of uploadFiles) {
-			if (uploadEntry.type == 'directory') {
-				for (var file of (await FileServerUtils.getRecursiveTree(uploadEntry.path))) {
-					data.paths.push(file.path);
+			if (uploadEntry.enabled) {
+				if (uploadEntry.type == 'directory') {
+					for (var file of (await FileServerUtils.getRecursiveTree(Global.convertOptumiPathToJupyterPath(uploadEntry.path)))) {
+						data.paths.push(Global.convertJupyterPathToOptumiPath(file.path));
+					}
+				} else {
+					data.paths.push(uploadEntry.path);
 				}
-			} else {
-				data.paths.push(uploadEntry.path);
 			}
 		}
 
@@ -607,21 +623,6 @@ export class App {
 			this._initializing.addUpdate(new Update('Initialization failed', ""));
 			this._initializing.addUpdate(new Update('error', ""));
 			this._initializing.addUpdate(new Update('stop', ""));
-		}).then((body: any) => {
-			if (body.files) {
-				for (let i = 0; i < body.files.length; i++) {
-					if (body.files[i] != '') {
-						this._files.push({
-							last_modified: body.filesmod[i],
-							name: (body.files[i] as string).split('/').pop(),
-							path: body.files[i],
-							size: +body.filessize[i],
-							type: 'file',
-							hash: body.hashes[i],
-						} as FileMetadata);
-					}
-				}
-			}
 		});
 		this.getLaunchStatus();
 	}
