@@ -69,7 +69,7 @@ export class AppComponent extends React.Component<IProps, IState> {
 		const init: RequestInit = {
 			method: 'POST',
 			body: JSON.stringify({
-				uuid: this.props.app.uuid,
+				workload: this.props.app.uuid,
 			}),
 		};
 		ServerConnection.makeRequest(
@@ -99,7 +99,8 @@ export class AppComponent extends React.Component<IProps, IState> {
 		const init: RequestInit = {
 			method: 'POST',
 			body: JSON.stringify({
-				uuid: this.props.app.uuid,
+				workload: this.props.app.uuid,
+				module: this.props.app.modules[0].uuid,
 			}),
 		};
 		ServerConnection.makeRequest(
