@@ -17,6 +17,7 @@ import { User } from '../User';
 import WarningPopup from '../../core/WarningPopup';
 import FormatUtils from '../../utils/FormatUtils';
 import ExtraInfo from '../../utils/ExtraInfo';
+import { App } from '../application/App';
 
 interface IProps {
     machine: Machine
@@ -42,13 +43,14 @@ export class MachineComponent extends React.Component<IProps, IState> {
         };
     }
 
-    private stopApp = (uuid: string): Promise<string> => {
+    private stopApp = (app: App): Promise<string> => {
 		const settings = ServerConnection.makeSettings();
 		const url = settings.baseUrl + "optumi/stop-notebook";
 		const init: RequestInit = {
 			method: 'POST',
 			body: JSON.stringify({
-				uuid: uuid,
+				workload: app.uuid,
+				module: app.modules[0].uuid,
 			}),
 		};
 		return ServerConnection.makeRequest(
@@ -67,7 +69,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
         const init: RequestInit = {
             method: 'POST',
             body: JSON.stringify({
-                uuid: uuid,
+                workload: uuid,
             }),
         };
         return ServerConnection.makeRequest(
@@ -195,7 +197,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
                                                     // We set these outside so they will span the job stop/delete as well
                                                     this.safeSetState({ waiting: true, spinning: false });
                                                     setTimeout(() => this.safeSetState({ spinning: true }), 1000);
-                                                    this.stopApp(app.uuid).then(() => this.handleDeleteClicked());
+                                                    this.stopApp(app).then(() => this.handleDeleteClicked());
                                                 } else {
                                                     // Only delete the machine after the job is deleted to avoid a race condition
                                                     // We set these outside so they will span the job stop/delete as well
