@@ -218,11 +218,11 @@ export class PopupMachineComponent extends React.Component<IProps, IState> {
                                 ) : this.state.selectedPanel == Page.STATUS ? (
                                     <>
                                         <div style={{ margin: '6px' }}>
-                                            {Machine.getStateMessage(this.props.machine.state) == '' ? 'Machine currently has no status' : 'Machine is currently ' + Machine.getStateMessage(this.props.machine.state).toLowerCase()}
+                                            {this.props.machine.getStateMessage() == '' ? 'Machine currently has no status' : 'Machine is currently ' + this.props.machine.getStateMessage().toLowerCase()}
                                         </div>
                                         {placedApp && (
                                             <div style={{ margin: '6px' }}>
-                                                {(placedApp.interactive ? 'Session' : 'Job') + " '" + placedApp.name + "' (" + placedApp.annotationOrRunNum + ") is " + (((placedApp.requisitioning.completed && !placedApp.requisitioning.error) && !placedApp.running.completed) ? 'running on' : 'waiting for') + ' this machine'}
+                                                {(placedApp.interactive ? 'Session' : 'Job') + " '" + placedApp.name + "' (" + placedApp.annotationOrRunNum + ") is " + (((placedApp.preparing.completed && !placedApp.preparing.error) && !placedApp.running.completed) ? 'running on' : 'waiting for') + ' this machine'}
                                             </div>
                                         )}
                                     </>
