@@ -78,13 +78,19 @@ async function activate(
 		const url = settings.baseUrl + 'optumi/version'
 		ServerConnection.makeRequest(url, {}, settings).then(response => {
 			if (response.status !== 200) throw new ServerConnection.ResponseError(response);
-			return response.text()
-		}).then((version: string) => {
+			return response.json()
+		}).then((data: any) => {
 			// Get the version from the server
 			// We do not want to start the extension until we know the version, it might mess with metadata
+			const version = data.version
+			const userHome = data.userHome
+			const jupyterHome = data.jupyterHome
+
 			console.log('JupyterLab extension jupyterlab-optumi version ' + version + ' is activated!');
 
 			Global.version = version
+			Global.userHome = userHome
+			Global.jupyterHome = jupyterHome
 			Global.metadata = new OptumiMetadataTracker(Global.tracker);
 		});
 
